@@ -175,7 +175,7 @@ def tagging(txt, debug=False):
 
 
 if __name__ == "__main__":
-    input_text = '2017-09-05T23:33:45 1.50-2.50m'
+    input_text = '152/2017/NĐ-CP'
     # input_text = ' '.join(word_tokenize(input_text))
     print(input_text)
     tags = tagging(input_text)
